@@ -10,7 +10,7 @@ from torch.distributions.utils import logits_to_probs, probs_to_logits, clamp_pr
 from torch.distributions import constraints
 from torch.distributions.transforms import SoftmaxTransform
 
-from .utils.custom_mlp import MLP, Exp
+from .utils.custom_mlp import MLP, Exp, ZeroBiasMLP
 from .utils.utils import CustomDataset, CustomDataset2, CustomDataset4, tensor_to_numpy, convert_to_tensor
 
 
@@ -73,6 +73,7 @@ class PerturbFlow(nn.Module):
                  config_enum: str = 'parallel',
                  use_cuda: bool = False,
                  seed: int = 42,
+                 zero_bias: bool = True,
                  dtype = torch.float32, # type: ignore
                  ):
         super().__init__()
@@ -96,6 +97,7 @@ class PerturbFlow(nn.Module):
         self.post_layer_fct = post_layer_fct
         self.post_act_fct = post_act_fct
         self.hidden_layer_activation = hidden_layer_activation
+        self.use_bias = not zero_bias
         
         self.codebook_weights = None
 
@@ -196,17 +198,29 @@ class PerturbFlow(nn.Module):
         if self.cell_factor_size>0:
             self.cell_factor_effect = nn.ModuleList()
             for i in np.arange(self.cell_factor_size):
-                self.cell_factor_effect.append(MLP(
-                    [self.latent_dim+1] + hidden_sizes + [self.latent_dim],
-                    activation=activate_fct,
-                    output_activation=None,
-                    post_layer_fct=post_layer_fct,
-                    post_act_fct=post_act_fct,
-                    allow_broadcast=self.allow_broadcast,
-                    use_cuda=self.use_cuda,
-                    bias=False,
-                )
-                )
+                if self.use_bias:
+                    self.cell_factor_effect.append(MLP(
+                        [self.latent_dim+1] + self.decoder_hidden_layers + [self.latent_dim],
+                        activation=activate_fct,
+                        output_activation=None,
+                        post_layer_fct=post_layer_fct,
+                        post_act_fct=post_act_fct,
+                        allow_broadcast=self.allow_broadcast,
+                        use_cuda=self.use_cuda,
+                        bias=True,
+                        )
+                    )
+                else:
+                    self.cell_factor_effect.append(ZeroBiasMLP(
+                        [self.latent_dim+1] + self.decoder_hidden_layers + [self.latent_dim],
+                        activation=activate_fct,
+                        output_activation=None,
+                        post_layer_fct=post_layer_fct,
+                        post_act_fct=post_act_fct,
+                        allow_broadcast=self.allow_broadcast,
+                        use_cuda=self.use_cuda,
+                        )
+                    )
             
         self.decoder_concentrate = MLP(
                 [self.latent_dim] + self.decoder_hidden_layers + [self.input_size],
