@@ -10,7 +10,7 @@ from torch.distributions.utils import logits_to_probs, probs_to_logits, clamp_pr
 from torch.distributions import constraints
 from torch.distributions.transforms import SoftmaxTransform
 
-from .utils.custom_mlp import MLP, Exp
+from .utils.custom_mlp import MLP, Exp, ZeroBiasMLP
 from .utils.utils import CustomDataset, CustomDataset2, CustomDataset4, tensor_to_numpy, convert_to_tensor
 
 
@@ -240,7 +240,6 @@ class SURE(nn.Module):
                 post_act_fct=post_act_fct,
                 allow_broadcast=self.allow_broadcast,
                 use_cuda=self.use_cuda,
-                bias=False,
             )
             
         self.decoder_concentrate = MLP(
