@@ -7,7 +7,7 @@ from .utils import find_partitions_greedy
 
 from .queue import PriorityQueue
 
-from .custom_mlp import MLP, Exp
+from .custom_mlp import MLP, Exp, ZeroBiasMLP
 
 # Importing modules
 #from . import utils
